@@ -30,7 +30,7 @@ redirected to the actual Wikipedia.
 =cut
 
 package App::Phoebe::Wikipedia;
-use App::Phoebe qw($log @extensions $full_url_regex success result);
+use App::Phoebe qw($log @extensions $full_url_regex success result gemini_link);
 use URI::Escape;
 use Modern::Perl;
 use MediaWiki::API;
@@ -113,7 +113,7 @@ sub wikipedia_serve_search {
     return;
   }
   result($stream, "20", "text/gemini;lang=$lang");
-  $stream->write("# Searching for " . uri_unescape($term) . "\n");
+  $stream->write("# Searching for " . encode_utf8(uri_unescape($term)) . "\n");
   foreach (@$articles) {
     wikipedia_print_link($stream, $lang, $_->{title}, 'text', $_->{title});
   }
